@@ -21,6 +21,7 @@
 #
 
 import os
+import sys
 import subprocess
 import pkg_resources
 from PyQt5 import QtWidgets, QtCore, QtGui  # pylint: disable=import-error
@@ -52,16 +53,17 @@ def _run_qrexec_repo(service, arg=''):
         check=False,
         env=env
     )
-    if p.stderr:
-        msg = QtCore.QCoreApplication.translate(
-                "GlobalSettings",
-                'qrexec call stderr was not empty')
-        raise exc.QubesException(msg + ' (%s)', p.stderr.decode('utf-8'))
     if p.returncode != 0:
         msg = QtCore.QCoreApplication.translate(
                 "GlobalSettings",
                 'qrexec call exited with non-zero return code')
-        raise exc.QubesException(msg + ' (%s)', p.returncode)
+        raise exc.QubesException(msg + ' (%s): %s',
+                p.returncode, p.stderr.decode('utf-8'))
+    if p.stderr:
+        msg = QtCore.QCoreApplication.translate(
+                "GlobalSettings",
+                '%s qrexec call stderr was not empty (%s)')
+        print(msg % (service, p.stderr.decode('utf-8')), file=sys.stderr)
     return p.stdout.decode('utf-8')
 
 
@@ -410,9 +412,9 @@ class GlobalSettingsWindow(ui_globalsettingsdlg.Ui_GlobalSettings,
                 # removed qmemman_algo.CACHE_FACTOR
 
                 try:
-                    qmemman_config_file = open(qmemman_config_path, 'a')
-                    self.qmemman_config.write(qmemman_config_file)
-                    qmemman_config_file.close()
+                    with open(qmemman_config_path, 'a', encoding='utf-8') \
+                            as qmemman_config_file:
+                        self.qmemman_config.write(qmemman_config_file)
                 except Exception as ex:  # pylint: disable=broad-except
                     self.errors.append(
                         "Failed to set memory settings due to {}".format(
@@ -432,32 +434,31 @@ class GlobalSettingsWindow(ui_globalsettingsdlg.Ui_GlobalSettings,
                 config_lines = []
 
                 try:
-                    qmemman_config_file = open(qmemman_config_path, 'r')
+                    with open(qmemman_config_path, 'r', encoding='utf-8') \
+                            as qmemman_config_file:
+                        for line in qmemman_config_file:
+                            if line.strip().startswith('vm-min-mem'):
+                                config_lines.append(lines_to_add['vm-min-mem'])
+                                del lines_to_add['vm-min-mem']
+                            elif line.strip().startswith('dom0-mem-boost'):
+                                config_lines.append(
+                                        lines_to_add['dom0-mem-boost'])
+                                del lines_to_add['dom0-mem-boost']
+                            else:
+                                config_lines.append(line)
                 except Exception as ex:  # pylint: disable=broad-except
                     self.errors.append(
                         "Failed to set memory settings due to {}".format(
                             str(ex)))
                     return
 
-                for line in qmemman_config_file:
-                    if line.strip().startswith('vm-min-mem'):
-                        config_lines.append(lines_to_add['vm-min-mem'])
-                        del lines_to_add['vm-min-mem']
-                    elif line.strip().startswith('dom0-mem-boost'):
-                        config_lines.append(lines_to_add['dom0-mem-boost'])
-                        del lines_to_add['dom0-mem-boost']
-                    else:
-                        config_lines.append(line)
-
-                qmemman_config_file.close()
-
                 for line in lines_to_add:
                     config_lines.append(line)
 
                 try:
-                    qmemman_config_file = open(qmemman_config_path, 'w')
-                    qmemman_config_file.writelines(config_lines)
-                    qmemman_config_file.close()
+                    with open(qmemman_config_path, 'w', encoding='utf-8') \
+                            as qmemman_config_file:
+                        qmemman_config_file.writelines(config_lines)
                 except Exception as ex:  # pylint: disable=broad-except
                     self.errors.append(
                         "Failed to set memory settings due to {}".format(
@@ -480,12 +481,12 @@ class GlobalSettingsWindow(ui_globalsettingsdlg.Ui_GlobalSettings,
         self.enable_updates_all.clicked.connect(self.__enable_updates_all)
         self.disable_updates_all.clicked.connect(self.__disable_updates_all)
 
-        self.repos = repos = dict()
+        self.repos = repos = {}
         try:
             for i in _run_qrexec_repo('qubes.repos.List').split('\n'):
                 lst = i.split('\0')
                 # Keyed by repo name
-                dct = repos[lst[0]] = dict()
+                dct = repos[lst[0]] = {}
                 dct['prettyname'] = lst[1]
                 dct['enabled'] = lst[2] == 'enabled'
         except exc.QubesException:
