@@ -1385,11 +1385,17 @@ class QubeManagerTest(unittest.TestCase):
             call_count = self._get_table_vminfo(
                 i).update.call_count
             if self._get_table_item(i, "Template") == target_vm_name:
-                self.assertGreater(call_count, 0)
+                self.assertGreater(call_count, 0,
+                        "'update' not called for VM '{}'".format(
+                            self._get_table_item(i, "Name")))
             elif self._get_table_item(i, "Name") == target_vm_name:
-                self.assertGreater(call_count, 0)
+                self.assertGreater(call_count, 0,
+                        "'update' not called for VM '{}'".format(
+                            self._get_table_item(i, "Name")))
             else:
-                self.assertEqual(call_count, 0)
+                self.assertEqual(call_count, 0,
+                        "Unexpected 'update' call for VM '{}'".format(
+                            self._get_table_item(i, "Name")))
 
     @unittest.mock.patch('qubesmanager.log_dialog.LogDialog')
     def test_500_logs(self, mock_log_dialog):
@@ -1605,9 +1611,8 @@ class QubeManagerThreadTest(unittest.TestCase):
         check_call.assert_called_once_with(
             ["/usr/bin/qubes-dom0-update", "--clean", "--gui"])
 
-    @unittest.mock.patch('builtins.open')
     @unittest.mock.patch('subprocess.call')
-    def test_21_update_vm_thread_running(self, mock_call, mock_open):
+    def test_21_update_vm_thread_running(self, mock_call):
         vm = unittest.mock.Mock(
             spec=['klass', 'is_running', 'run_service_for_stdio', 'run_service'],
             **{'is_running.return_value': True})
@@ -1619,20 +1624,13 @@ class QubeManagerThreadTest(unittest.TestCase):
 
         thread.run()
 
-        mock_open.assert_called_with(
-            '/usr/libexec/qubes-manager/dsa-4371-update', 'rb')
-
-        vm.run_service_for_stdio.assert_called_once_with(
-            "qubes.VMShell", user='root', input=unittest.mock.ANY)
-
         vm.run_service.assert_called_once_with(
             "qubes.InstallUpdatesGUI", user="root", wait=False)
 
         self.assertEqual(mock_call.call_count, 0)
 
-    @unittest.mock.patch('builtins.open')
     @unittest.mock.patch('subprocess.call')
-    def test_22_update_vm_thread_not_running(self, mock_call, mock_open):
+    def test_22_update_vm_thread_not_running(self, mock_call):
         vm = unittest.mock.Mock(
             spec=['klass', 'is_running', 'run_service_for_stdio',
                   'run_service', 'start', 'name'],
@@ -1644,18 +1642,12 @@ class QubeManagerThreadTest(unittest.TestCase):
         thread = qube_manager.UpdateVMThread(vm)
         thread.run()
 
-        mock_open.assert_called_with(
-            '/usr/libexec/qubes-manager/dsa-4371-update', 'rb')
-
         vm.start.assert_called_once_with()
 
-        vm.run_service_for_stdio.assert_called_once_with(
-            "qubes.VMShell", user='root', input=unittest.mock.ANY)
-
         vm.run_service.assert_called_once_with(
             "qubes.InstallUpdatesGUI", user="root", wait=False)
 
-        self.assertEqual(mock_call.call_count, 1)
+        self.assertEqual(mock_call.call_count, 0)
 
     @unittest.mock.patch('builtins.open')
     @unittest.mock.patch('subprocess.check_call')
